Struct KeyGrid
Source struct KeyGrid<const ROW: usize, const COL: usize> {
cells: [[KeyState; COL]; ROW],
}
A 2D grid of [KeyState] values representing the current state of all keys.
The key state for each position in the matrix.
Returns a mutable reference to the [KeyState] at the given row and
column, or [None] if either index is out of bounds.
Creates a new KeyGrid with all keys initialized to the released
state.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.